@@ -18,6 +18,10 @@ private:
   QVBoxLayout* dialogLayout;
   QVBoxLayout* configLayout;
   QHBoxLayout* tagsLayout;
+  QVBoxLayout* scrollLayout;
+  QWidget* scrollW;
+  
+  QScrollArea* scrArea;
   
   QGroupBox* playlistBox;
   QVBoxLayout* playlistLayout;
