@@ -221,8 +221,10 @@ void UI::settingsDialogAccepted()
 {
   //qDebug()<<"Setting Dialog Accepted";
   bool tmpUseTags=parent->config->useTags;
+  bool tmpUpdateOnPlay=parent->config->updateOnPlay;
   settingsdialog->getConfig(parent->config);
-  if((tmpUseTags==false)&&(parent->config->useTags==true))
+  if(((tmpUseTags==false)&&(parent->config->useTags==true))||
+   ((tmpUpdateOnPlay==true)&&(parent->config->updateOnPlay==false)&&(parent->config->useTags==true)))
     parent->engine->startMetaUpdater(true);
   
   folder->refreshWithNewMusicPath(parent->config->musicFolder);
