@@ -12,7 +12,7 @@ UIControl::UIControl(UPlay* parent)
 	buttonPlay = new QPushButton(s->standardIcon(QStyle::SP_MediaPlay),"");
 	buttonNext = new QPushButton(s->standardIcon(QStyle::SP_MediaSkipForward),"");
 	buttonToggle = new QPushButton(s->standardIcon(QStyle::SP_FileIcon),"");
-	random = new QCheckBox("Random");
+	random = new QCheckBox(tr("Random"));
 
 //	buttonNext->setFixedSize(30,30);	
 //	buttonStop->setFixedSize(30,30);
@@ -60,7 +60,11 @@ UIControl::~UIControl()
 void
 UIControl::randomChanged(int state)
 {
-	parent->ui->random = state ? true : false;
+	//parent->ui->random = state ? true : false;
+	if (state)
+	  parent->config->random = true;
+	else
+	  parent->config->random = false;
 }
 
 void
