@@ -12,8 +12,8 @@ UIFolder::UIFolder(UPlay* parent, QString musicPath)
 	
 	layout->addWidget(listWidget);
 
-	buttonAdd = new QPushButton("Add");
-	buttonRepl = new QPushButton("Replace");
+	buttonAdd = new QPushButton(tr("Add"));
+	buttonRepl = new QPushButton(tr("Replace"));
 	layoutControlF = new QHBoxLayout;
 	layoutControlF ->addWidget(buttonAdd);
 	layoutControlF ->addStretch();
@@ -44,7 +44,7 @@ UIFolder::UIFolder(UPlay* parent, QString musicPath)
 
 	// Filters
 		// Audios
-	filters << "*.mp3" << "*.wav" << "*.wma" << "*.mpc" << "*.m4a" << "*.ogg";
+	filters << "*.mp3" << "*.wav" << "*.wma" << "*.mpc" << "*.m4a" << "*.ogg" << "*.aac";
 		// Videos
 //	filters << "*.avi" << "*.mpg";
 		// System
@@ -87,7 +87,11 @@ UIFolder::refreshDirContent()
 	QFileInfo fi;
 
 	tmp.setSorting(QDir::DirsFirst | QDir::IgnoreCase);
-	tmp.setFilter(QDir::AllDirs | QDir::Files);
+	if(parent->config->showHidden)
+	  tmp.setFilter(QDir::AllDirs | QDir::Files | QDir::Hidden );
+	else
+	  tmp.setFilter(QDir::AllDirs | QDir::Files);
+	  
 	tmp.setNameFilters(filters);
 
 	listWidget->clear();
