@@ -6,6 +6,7 @@
 
 #include "Engine.h"
 #include "UI.h"
+#include "Config.h"
 
 class UPlay : public QApplication
 {
@@ -25,6 +26,7 @@ class UPlay : public QApplication
 		 * The ui
 		 */
 		UI* ui;
+		Config* config;
 
 		/*
 		 * To restore from a file the content of the playlist
